@@ -23,7 +23,7 @@ public:
     RationalWidget(QWidget * parent, const QString &pnumber, const int pperiodStart = 1, const int pperiodLength = 0);
 
     /** destructor */
-    ~RationalWidget();
+    ~RationalWidget() override;
 
     /** set the task to be displayed */
     void setRational(const QString &pnumber, const int pperiodStart = 1, const int pperiodLength = 0);
@@ -40,7 +40,7 @@ private:
     int m_periodLength;
 
     /** overriding the paint event of FractionBaseWidget */
-    void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent*) override;
 };
 
 #endif
